@@ -1,10 +1,14 @@
 """
-PiCloud environment management.
-This module allows the user to manage their environments on PiCloud.
+Science VM environment management.
+This module allows the user to manage their environments on Science VM.
 See documentation at http://docs.scivm.com
 """
 from __future__ import absolute_import
 """
+Copyright (c) 2014 `Science Automation Inc. <http://www.scivm.com>`_.  All rights reserved.
+
+email: support@scivm.com
+
 Copyright (c) 2013 `PiCloud, Inc. <http://www.picloud.com>`_.  All rights reserved.
 
 email: contact@picloud.com
@@ -20,8 +24,8 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.
 
 You should have received a copy of the GNU Lesser General Public
-License along with this package; if not, see 
-http://www.gnu.org/licenses/lgpl-2.1.html    
+License along with this package; if not, see
+http://www.gnu.org/licenses/lgpl-2.1.html
 """
 try:
     import json
@@ -36,7 +40,7 @@ import sys
 import string
 import time
 
-import cloud
+import scicloud as cloud
 from .cloudlog import stdout as print_stdout, stderr as print_stderr
 from .util import credentials
 from .util import common
@@ -183,9 +187,9 @@ def modify(name):
 def save(name):
     """Saves the current modified version of the environment, without tearing
     down the setup server.
-    
+
     * name: name of the environment to save
-    
+
     This is a blocking function.  When it returns without errors, the new
     version of the environment is available for use by all workers.
     """
@@ -196,9 +200,9 @@ def save(name):
 def save_shutdown(name):
     """Saves the current modified version of the environment, and tears down
     the setup server when saving is done.
-    
+
     * name: name of the environment to save
-    
+
     This is a blocking function.  When it returns without errors, the new
     version of the environment is available for use by all workers.
     """
@@ -208,7 +212,7 @@ def save_shutdown(name):
 
 def shutdown(name):
     """Tears down the setup server without saving the environment modification.
-    
+
     * name: name of the environment to save
     """
     resp = _send_env_request('shutdown', {'env_name': name})
@@ -245,7 +249,7 @@ def clone(parent_name, new_name=None, new_desc=None):
 
 def delete(name):
     """Deletes and existing environment.
-    
+
     * name: Name of the environment to save
     """
     resp = _send_env_request('delete', {'env_name': name})
@@ -255,7 +259,7 @@ def get_setup_hostname(name):
     """Returns the hostname of the setup server where environment can be
     modified.  raises exception if the environment does not have a setup server
     already launched.
-    
+
     * name: name of the environment whose setup server hostname is desired
     """
     env_info = wait_for_edit(name, _ACTION_IDLE)
@@ -270,7 +274,7 @@ def get_key_path():
 
 def ssh(name, cmd=None):
     """Creates an ssh session to the environment setup server.
-    
+
     * name: Name of the environment to make an ssh connection
     * cmd: By default, this function creates an interactive ssh session.
         If cmd is given, however, it executes the cmd on the setup server
@@ -284,7 +288,7 @@ def ssh(name, cmd=None):
         if stdout:
             sys.stdout.write(stdout)
         if stderr:
-            sys.stderr.write(stderr)        
+            sys.stderr.write(stderr)
         sys.exit(status)
 
     if cmd and stdout:
@@ -306,11 +310,11 @@ def rsync(src_path, dest_path, delete=False, pipe_output=False):
 
     Note that the colon is what indicates this is an environment path
     specification.
-    
+
     *src_path* can be a list of paths, all of which should either be local
     paths, or environment paths. If *src_path* is a directory, a trailing slash
     indicates that its contents should be rsynced, while ommission of slash
-    would lead to the directory itself being rsynced to the environment. 
+    would lead to the directory itself being rsynced to the environment.
 
     Example::
 
@@ -323,7 +327,7 @@ def rsync(src_path, dest_path, delete=False, pipe_output=False):
 
     will copy all the contents of 'dataset1' to the home directory of user
     scivm. See rsync manual for more information.
-    
+
     If *delete* is True, files that exist in *dest_path* but not in *src_path*
     will be deleted.  By default, such files will not be removed.
     """
@@ -334,7 +338,7 @@ def rsync(src_path, dest_path, delete=False, pipe_output=False):
                         (src_path, dest_path))
     local_paths = common.parse_local_paths(l_paths)
     env_name, env_paths = common.parse_remote_paths(r_paths)
-    
+
     hostname = get_setup_hostname(env_name)
     try:
         r_base = 'scivm@%s:' % hostname
@@ -357,7 +361,7 @@ def rsync(src_path, dest_path, delete=False, pipe_output=False):
 
 def run_script(name, filename):
     """Runs a script on the environment setup server, and returns the output.
-    
+
     * name: Environment whose setup server should run the script
     filename: local path where the script to be run can be found
     """
@@ -395,7 +399,7 @@ def _wait_for(name, action, invalid_actions=None, poll_frequency=2,
     invalid_actions = invalid_actions or []
     if not hasattr(invalid_actions, '__iter__'):
         invalid_actions = [invalid_actions]
-    
+
     for _ in xrange(max_poll_duration / poll_frequency):
         resp = list_envs(name)
 
@@ -426,6 +430,6 @@ def _wait_for(name, action, invalid_actions=None, poll_frequency=2,
             pass
 
         time.sleep(poll_frequency)
-        
+
     raise cloud.CloudException('Environment operation timed out. '
                                'Please contact PiCloud support.')
